diff --git a/Calorimeter/CaloLocalHadCalib/share/GetH6LCSinglePionsPerf_cbt.py b/Calorimeter/CaloLocalHadCalib/share/GetH6LCSinglePionsPerf_cbt.py
index adec358632c3ceec4ec56c1590beeef9a92d1ba1..f155390775d04c36bd3e4188a5b9eb302656274f 100644
--- a/Calorimeter/CaloLocalHadCalib/share/GetH6LCSinglePionsPerf_cbt.py
+++ b/Calorimeter/CaloLocalHadCalib/share/GetH6LCSinglePionsPerf_cbt.py
@@ -81,7 +81,7 @@ from RecExConfig.ObjKeyStore import ObjKeyStore, objKeyStore
 oks = ObjKeyStore()
 oks.addStreamESD('CaloCellContainer', ['AllCalo'] )
 
-from AthenaCommon.AppMgr import athFilterSeq
+from AthenaCommon.AppMgr import athMasterSeq
 
 # splitting DM container into two parts to get rid from DM outside of our quadrant
 from TBRec.TBRecConf import TBDMContainerSplitter
@@ -89,7 +89,7 @@ DMContSplit = TBDMContainerSplitter()
 DMContSplit.InputDMContainer = "LArCalibrationHitDeadMaterial"
 DMContSplit.OutputDM_Calo = "LArCalibrationHitDeadMaterial_Calo"
 DMContSplit.OutputDM_Leak = "LArCalibrationHitDeadMaterial_Leakage"
-athFilterSeq += DMContSplit
+athMasterSeq += DMContSplit
 
 
 # ----------------- new topo clustering --------------
@@ -208,7 +208,7 @@ if doBeamQuality:
   #TBBeamQuality.CheckClusters = True
   #TBBeamQuality.CheckTrackReco = False
 
-  athFilterSeq  += TBBeamQuality
+  athMasterSeq  += TBBeamQuality
 
 # =============================================================================
 #
diff --git a/Calorimeter/CaloLocalHadCalib/share/cl_w_ooc_H6.py b/Calorimeter/CaloLocalHadCalib/share/cl_w_ooc_H6.py
index b602c49a9403bc037f7616d356b5a99e053e9451..db154f50d917642b5649b6a6874b52e63ef767e5 100644
--- a/Calorimeter/CaloLocalHadCalib/share/cl_w_ooc_H6.py
+++ b/Calorimeter/CaloLocalHadCalib/share/cl_w_ooc_H6.py
@@ -98,7 +98,7 @@ from RecExConfig.ObjKeyStore import ObjKeyStore, objKeyStore
 oks = ObjKeyStore()
 oks.addStreamESD('CaloCellContainer', ['AllCalo'] )
 
-from AthenaCommon.AppMgr import athFilterSeq
+from AthenaCommon.AppMgr import athMasterSeq
 
 # splitting DM container into two parts to get rid from DM outside of our quadrant
 from TBRec.TBRecConf import TBDMContainerSplitter
@@ -106,7 +106,7 @@ DMContSplit = TBDMContainerSplitter()
 DMContSplit.InputDMContainer = "LArCalibrationHitDeadMaterial"
 DMContSplit.OutputDM_Calo = "LArCalibrationHitDeadMaterial_Calo"
 DMContSplit.OutputDM_Leak = "LArCalibrationHitDeadMaterial_Leakage"
-athFilterSeq += DMContSplit
+athMasterSeq += DMContSplit
 
 
 # ----------------- new topo clustering --------------
@@ -196,7 +196,7 @@ if doBeamQuality:
   #TBBeamQuality.CheckClusters = True
   #TBBeamQuality.CheckTrackReco = False
 
-  athFilterSeq  += TBBeamQuality
+  athMasterSeq  += TBBeamQuality
 
 # =============================================================================
 #
diff --git a/Calorimeter/CaloLocalHadCalib/share/deadmaterialtree_ctb.py b/Calorimeter/CaloLocalHadCalib/share/deadmaterialtree_ctb.py
index 8b3cec77117229c4da1f442c228038e11e616ad5..cff0f79ffd1536c815ac859b7f5bae16dc1233f5 100644
--- a/Calorimeter/CaloLocalHadCalib/share/deadmaterialtree_ctb.py
+++ b/Calorimeter/CaloLocalHadCalib/share/deadmaterialtree_ctb.py
@@ -92,7 +92,7 @@ oks = ObjKeyStore()
 oks.addStreamESD('CaloCellContainer', ['AllCalo'] )
 
 
-from AthenaCommon.AppMgr import athFilterSeq
+from AthenaCommon.AppMgr import athMasterSeq
 
 # splitting DM container into two parts to get rid from DM outside of our quadrant
 from TBRec.TBRecConf import TBDMContainerSplitter
@@ -100,7 +100,7 @@ DMContSplit = TBDMContainerSplitter()
 DMContSplit.InputDMContainer = "LArCalibrationHitDeadMaterial"
 DMContSplit.OutputDM_Calo = "LArCalibrationHitDeadMaterial_Calo"
 DMContSplit.OutputDM_Leak = "LArCalibrationHitDeadMaterial_Leakage"
-athFilterSeq += DMContSplit
+athMasterSeq += DMContSplit
  
 
 # ----------------- new topo clustering --------------
@@ -204,7 +204,7 @@ if doBeamQuality:
   TBBeamQuality.CheckTrackReco = False
 
   print TBBeamQuality
-  athFilterSeq  += TBBeamQuality
+  athMasterSeq  += TBBeamQuality
 
 # =============================================================================
 #
diff --git a/Control/AthenaCommon/python/AlgSequence.py b/Control/AthenaCommon/python/AlgSequence.py
index 107e372c1019d492803305bd096b025c345ce9cf..201f6ab89e5046620d81afb5c1913896066f631b 100755
--- a/Control/AthenaCommon/python/AlgSequence.py
+++ b/Control/AthenaCommon/python/AlgSequence.py
@@ -163,10 +163,11 @@ def dumpMasterSequence():
 
     # otherwise, manually do it...
     dumpSequence( AthSequencer ("AthMasterSeq"), indent=0 )
-    dumpSequence( AthSequencer ("AthFilterSeq"), indent=1 )
-    dumpSequence( AthSequencer ("AthBeginSeq"),  indent=2 )
-    dumpSequence( AthSequencer ("AthCondSeq"),   indent=3 )
-    dumpSequence( AlgSequence  ("TopAlg"),       indent=3 )
-    dumpSequence( AthSequencer ("AthEndSeq"),    indent=2 )
-    dumpSequence( AthSequencer ("AthOutSeq"),    indent=1 )
-    dumpSequence( AthSequencer ("AthRegSeq"),    indent=1 )
+    dumpSequence( AthSequencer ("athAlgEvtSeq"), indent=1 )
+    dumpSequence( AthSequencer ("athBeginSeq"),  indent=2 )
+    dumpSequence( AlgSequence  ("athAllAlgSeq"), indent=2 )
+    dumpSequence( AthSequencer ("athCondSeq"),   indent=3 )
+    dumpSequence( AthSequencer ("athAlgSeq"),    indent=3 )
+    dumpSequence( AthSequencer ("athEndSeq"),    indent=2 )
+    dumpSequence( AthSequencer ("athOutSeq"),    indent=1 )
+    dumpSequence( AthSequencer ("athRegSeq"),    indent=1 )
diff --git a/Control/AthenaCommon/python/AppMgr.py b/Control/AthenaCommon/python/AppMgr.py
index f030246421887693627bc57e8817f907dd79bfff..a746e0fa8f8d9489964abaabe78bc835d8964695 100755
--- a/Control/AthenaCommon/python/AppMgr.py
+++ b/Control/AthenaCommon/python/AppMgr.py
@@ -18,7 +18,6 @@ __author__  = 'Wim Lavrijsen (WLavrijsen@lbl.gov)'
 
 __all__ = [ 'theApp', 'ServiceMgr', 'ToolSvc', 'AuditorSvc', 'theAuditorSvc',
             'athMasterSeq',
-            'athFilterSeq',
             'athCondSeq',
             'athAlgSeq',    'topSequence',
             'athOutSeq',
@@ -251,7 +250,7 @@ class AthAppMgr( AppMgr ):
 
    def __build_master_sequence (self):
       """helper method to build the top-level AthSequencer from all bits and
-         pieces : AthMasterSeq, AthFilterSeq, AthAlgSeq, AthOutSeq, AthRegSeq
+         pieces : AthMasterSeq, AthAlgSeq, AthOutSeq, AthRegSeq
       """
       from . import AlgSequence as _as
       from AthenaServices.AthenaServicesConf import AthIncFirerAlg as IFA
@@ -259,11 +258,10 @@ class AthAppMgr( AppMgr ):
 
       def _build():
          Logging.log.debug ("building master sequence...")
-         athMasterSeq = _as.AthSequencer ("AthMasterSeq",Sequential = True, StopOverride=True)
-         athFilterSeq = _as.AthSequencer ("AthFilterSeq")
+         athMasterSeq = _as.AthSequencer ("AthMasterSeq",Sequential = True)
          athBeginSeq  = _as.AthSequencer ("AthBeginSeq",Sequential=True)
          athCondSeq   = _as.AthSequencer ("AthCondSeq")
-         athAlgSeq    = _as.AthSequencer ("AthAlgSeq")
+         athAlgSeq    = _as.AthSequencer ("AthAlgSeq",IgnoreFilterPassed=True)
          athEndSeq    = _as.AthSequencer ("AthEndSeq",Sequential=True)
          athOutSeq    = _as.AthSequencer ("AthOutSeq")
          athRegSeq    = _as.AthSequencer ("AthRegSeq")
@@ -304,8 +302,6 @@ class AthAppMgr( AppMgr ):
          ipa2=IPA("IncidentProcAlg2")
          athEndSeq += ipa2
 
-         athMasterSeq += athFilterSeq
-
          # XXX: should we discard empty sequences ?
          #      might save some CPU and memory...
 
@@ -326,7 +322,7 @@ class AthAppMgr( AppMgr ):
          athAlgEvtSeq += athAllAlgSeq
          athAlgEvtSeq += athEndSeq
 
-         athFilterSeq += athAlgEvtSeq
+         athMasterSeq += athAlgEvtSeq
          athMasterSeq += athOutSeq
          athMasterSeq += athRegSeq
          
@@ -972,25 +968,22 @@ def AuditorSvc():             # backwards compatibility
 ### create default sequences:
 #      athMasterSeq
 #         |
-#         +-- athFilterSeq
-#                |
-#                +--- athAlgEvtSeq
-#                        |
-#                        +--- athBeginSeq
-#                        |
-#                        +--- athAllAlgSeq
-#                                |
-#                                +--- athCondSeq
-#                                |
-#                                +--- athAlgSeq == TopAlg
-#                        |
-#                        +--- athEndSeq
+#         +--- athAlgEvtSeq
+#                 |
+#                 +--- athBeginSeq
+#                 |
+#                 +--- athAllAlgSeq
+#                         |
+#                         +--- athCondSeq (after athAlgSeq in MT)
+#                         |
+#                         +--- athAlgSeq == TopAlg
+#                 |
+#                 +--- athEndSeq
 #         |
 #         +--- athOutSeq
 #         |
 #         +--- athRegSeq
 athMasterSeq = AlgSequence.AthSequencer( "AthMasterSeq" )
-athFilterSeq = AlgSequence.AthSequencer( "AthFilterSeq" )
 athCondSeq   = AlgSequence.AthSequencer( "AthCondSeq" )
 athAlgSeq    = AlgSequence.AthSequencer( "AthAlgSeq" )
 athOutSeq    = AlgSequence.AthSequencer( "AthOutSeq" )
diff --git a/Control/AthenaCommon/python/ConfigurationShelve.py b/Control/AthenaCommon/python/ConfigurationShelve.py
index 4038da3a33a3e1e818c25f02f16e78789c085cad..eea73d78f42253b12051090f26a0006aae3432c1 100644
--- a/Control/AthenaCommon/python/ConfigurationShelve.py
+++ b/Control/AthenaCommon/python/ConfigurationShelve.py
@@ -101,7 +101,6 @@ class ConfigurationJar( object ):
 
       from . import AlgSequence as _as
       self.athMasterSeq = _as.AthSequencer ("AthMasterSeq")
-      self.athFilterSeq = _as.AthSequencer ("AthFilterSeq")
       self.TopSequence  = _as.AlgSequence  ("TopAlg")
       self.athAlgSeq    = _as.AthSequencer ("AthAlgSeq")
       self.athOutSeq    = _as.AthSequencer ("AthOutSeq")
@@ -123,7 +122,6 @@ class ConfigurationJar( object ):
       d[ 'name' ] = self.name
 
       d[ 'AthMasterSeq' ]  = self.athMasterSeq
-      d[ 'AthFilterSeq' ]  = self.athFilterSeq
       d[ 'AthAlgSeq' ]     = self.athAlgSeq
       d[ 'TopSequence' ]   = self.TopSequence
       d[ 'AthOutSeq' ]     = self.athOutSeq
diff --git a/Control/AthenaServices/share/AthTPCnvSvc.ref b/Control/AthenaServices/share/AthTPCnvSvc.ref
index d6f596cea47152801d2c1fa85abc23d015651757..1f3ac8706b287eec9f0ffe1b137308794a60c9da 100644
--- a/Control/AthenaServices/share/AthTPCnvSvc.ref
+++ b/Control/AthenaServices/share/AthTPCnvSvc.ref
@@ -40,13 +40,12 @@ Py:Configurable     ERROR attempt to add a duplicate (AthBeginSeq.BeginIncFiring
 Py:Configurable     ERROR attempt to add a duplicate (AthBeginSeq.IncidentProcAlg1) ... dupe ignored
 Py:Configurable     ERROR attempt to add a duplicate (AthEndSeq.EndIncFiringAlg) ... dupe ignored
 Py:Configurable     ERROR attempt to add a duplicate (AthEndSeq.IncidentProcAlg2) ... dupe ignored
-Py:Configurable     ERROR attempt to add a duplicate (AthMasterSeq.AthFilterSeq) ... dupe ignored
 Py:Configurable     ERROR attempt to add a duplicate (AthAllAlgSeq.AthCondSeq) ... dupe ignored
 Py:Configurable     ERROR attempt to add a duplicate (AthAllAlgSeq.AthAlgSeq) ... dupe ignored
 Py:Configurable     ERROR attempt to add a duplicate (AthAlgEvtSeq.AthBeginSeq) ... dupe ignored
 Py:Configurable     ERROR attempt to add a duplicate (AthAlgEvtSeq.AthAllAlgSeq) ... dupe ignored
 Py:Configurable     ERROR attempt to add a duplicate (AthAlgEvtSeq.AthEndSeq) ... dupe ignored
-Py:Configurable     ERROR attempt to add a duplicate (AthFilterSeq.AthAlgEvtSeq) ... dupe ignored
+Py:Configurable     ERROR attempt to add a duplicate (AthMasterSeq.AthAlgEvtSeq) ... dupe ignored
 Py:Configurable     ERROR attempt to add a duplicate (AthMasterSeq.AthOutSeq) ... dupe ignored
 Py:Configurable     ERROR attempt to add a duplicate (AthMasterSeq.AthRegSeq) ... dupe ignored
 StatusCodeSvc        INFO reinitialize
diff --git a/Control/PerformanceMonitoring/PerfMonComps/python/PerfMonSerializer.py b/Control/PerformanceMonitoring/PerfMonComps/python/PerfMonSerializer.py
index ccada5ed49637d50f18357409a66923e6bfa876b..20aeab2eb4c3aa9dc8e99e6e54055b1a266ea06c 100644
--- a/Control/PerformanceMonitoring/PerfMonComps/python/PerfMonSerializer.py
+++ b/Control/PerformanceMonitoring/PerfMonComps/python/PerfMonSerializer.py
@@ -637,7 +637,6 @@ def create_cachegrind_files(fname='ntuple.pmon.gz', domainsdb=None):
     if domainsdb is None:
         domainsdb = extract_pmon_infos(fname)['domains_a2d']
     for n in ('PerfMonSlice', 'AthMasterSeq',
-              'AthFilterSeq',
               'AthAlgSeq',
               'AthOutSeq',
               'AthRegSeq',):
diff --git a/DataQuality/GoodRunsLists/src/GRLSelectorAlg.h b/DataQuality/GoodRunsLists/src/GRLSelectorAlg.h
index 0ef736fde7507bc0e237813bfae2ac4849e20209..6b3c7156a9dbf3922f3fa99c2b048fb435133780 100644
--- a/DataQuality/GoodRunsLists/src/GRLSelectorAlg.h
+++ b/DataQuality/GoodRunsLists/src/GRLSelectorAlg.h
@@ -12,9 +12,9 @@
 
 ///Author: will buttinger
 ///To use this alg in your joboptions:
-///filterseq = CfgMgr.AthSequencer("AthFilterSeq")
+///masterseq = CfgMgr.AthSequencer("AthMasterSeq")
 ///ToolSvc += CfgMgr.GoodRunsListSelectionTool("myGRLTool",GoodRunsListVec=["my.grl.xml"])
-///filterseq += CfgMgr.GRLSelectorAlg(Tool=ToolSvc.myGRLTool)
+///masterseq += CfgMgr.GRLSelectorAlg(Tool=ToolSvc.myGRLTool)
 
 
 class GRLSelectorAlg: public ::AthAlgorithm { 
diff --git a/Generators/EvgenJobTransforms/share/skeleton.ABtoEVGEN.py b/Generators/EvgenJobTransforms/share/skeleton.ABtoEVGEN.py
index 21e6e3fc2d4ce9101d7f772fde167fcd6d21e880..78fbd5dcaed5178d0f63aec395b8dc55826f0460 100644
--- a/Generators/EvgenJobTransforms/share/skeleton.ABtoEVGEN.py
+++ b/Generators/EvgenJobTransforms/share/skeleton.ABtoEVGEN.py
@@ -17,12 +17,12 @@ genSeq = acam.athMasterSeq.EvgenGenSeq
 #fixSeq = acam.athMasterSeq.EvgenFixSeq
 acam.athMasterSeq += acas.AlgSequence("EvgenPreFilterSeq")
 prefiltSeq = acam.athMasterSeq.EvgenPreFilterSeq
-acam.athFilterSeq += acas.AlgSequence("EvgenTestSeq")
-testSeq = acam.athFilterSeq.EvgenTestSeq
+acam.athMasterSeq += acas.AlgSequence("EvgenTestSeq")
+testSeq = acam.athMasterSeq.EvgenTestSeq
 ## NOTE: LogicalExpressionFilter is an algorithm, not a sequence
 from EvgenProdTools.LogicalExpressionFilter import LogicalExpressionFilter
-acam.athFilterSeq += LogicalExpressionFilter("EvgenFilterSeq")
-filtSeq = acam.athFilterSeq.EvgenFilterSeq
+acam.athMasterSeq += LogicalExpressionFilter("EvgenFilterSeq")
+filtSeq = acam.athMasterSeq.EvgenFilterSeq
 topSeq = acas.AlgSequence()
 anaSeq = topSeq
 topSeq += acas.AlgSequence("EvgenPostSeq")
diff --git a/Generators/EvgenJobTransforms/share/skeleton.GENtoEVGEN.py b/Generators/EvgenJobTransforms/share/skeleton.GENtoEVGEN.py
index f9d0e418bb38e3bb0416acf93b7c715ac87e0109..cc7faf5a6edf18162cdfb6b351ebcc494c82e23a 100644
--- a/Generators/EvgenJobTransforms/share/skeleton.GENtoEVGEN.py
+++ b/Generators/EvgenJobTransforms/share/skeleton.GENtoEVGEN.py
@@ -17,12 +17,12 @@ acam.athMasterSeq += acas.AlgSequence("EvgenFixSeq")
 fixSeq = acam.athMasterSeq.EvgenFixSeq
 acam.athMasterSeq += acas.AlgSequence("EvgenPreFilterSeq")
 prefiltSeq = acam.athMasterSeq.EvgenPreFilterSeq
-acam.athFilterSeq += acas.AlgSequence("EvgenTestSeq")
-testSeq = acam.athFilterSeq.EvgenTestSeq
+acam.athMasterSeq += acas.AlgSequence("EvgenTestSeq")
+testSeq = acam.athMasterSeq.EvgenTestSeq
 ## NOTE: LogicalExpressionFilter is an algorithm, not a sequence
 from EvgenProdTools.LogicalExpressionFilter import LogicalExpressionFilter
-acam.athFilterSeq += LogicalExpressionFilter("EvgenFilterSeq")
-filtSeq = acam.athFilterSeq.EvgenFilterSeq
+acam.athMasterSeq += LogicalExpressionFilter("EvgenFilterSeq")
+filtSeq = acam.athMasterSeq.EvgenFilterSeq
 topSeq = acas.AlgSequence()
 anaSeq = topSeq
 topSeq += acas.AlgSequence("EvgenPostSeq")
diff --git a/InnerDetector/InDetExample/InDetAlignExample/ErrorScaling/jobOptionsAlignmentSet.py b/InnerDetector/InDetExample/InDetAlignExample/ErrorScaling/jobOptionsAlignmentSet.py
index e8825063bf9059baba14937c323d295bbe1d6b4e..8b0504f43d47f601181cc10ada10d40285b912e9 100644
--- a/InnerDetector/InDetExample/InDetAlignExample/ErrorScaling/jobOptionsAlignmentSet.py
+++ b/InnerDetector/InDetExample/InDetAlignExample/ErrorScaling/jobOptionsAlignmentSet.py
@@ -49,7 +49,7 @@ if doMisAlign:
 ## here, the (default) top sequence is used:
 ### from AthenaCommon.AlgSequence import AlgSequence, AthSequencer
 ### job = AlgSequence()
-### seq = AthSequencer("AthFilterSeq")
+### seq = AthSequencer("AthMasterSeq")
 
 #-----------------
 # This block handles good run lists. Uncomment to enable goodrunlist
@@ -64,10 +64,10 @@ if doMisAlign:
 #seq.GRLTriggerAlg1.GoodRunsListArray = ['MyLBCollection'] ## pick up correct name from inside xml file!
 #-----------------
 
-## AthFilterSeq is always executed before the top sequence, and is configured such that
+## AthMasterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
-## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
+## In short, the sequence AthMasterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 
 ## Add the ntuple dumper to the top sequence, as usual
diff --git a/InnerDetector/InDetExample/InDetAlignExample/share/loadInDetRec_EoverPMaps.py b/InnerDetector/InDetExample/InDetAlignExample/share/loadInDetRec_EoverPMaps.py
index 3ec848ba23b7dedbc1c607c061da26a5b2b3a282..2dfa0378e07d0561fc2bbb9a9d493f7ea273851a 100755
--- a/InnerDetector/InDetExample/InDetAlignExample/share/loadInDetRec_EoverPMaps.py
+++ b/InnerDetector/InDetExample/InDetAlignExample/share/loadInDetRec_EoverPMaps.py
@@ -55,7 +55,7 @@ GoodRunsListSelectorTool.GoodRunsListVec  = [loadInDetRec_Options["GoodRunList"]
 
 from AthenaCommon.AlgSequence import AlgSequence, AthSequencer
 job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 from GoodRunsListsUser.GoodRunsListsUserConf import *
 seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
diff --git a/InnerDetector/InDetExample/InDetBeamSpotExample/python/FilterUtils.py b/InnerDetector/InDetExample/InDetBeamSpotExample/python/FilterUtils.py
index f8a26cfa30a4b997246d4160dea46eeaf7cc357f..8dd2b59e6d347529fee14095d02b9bea8388d869 100644
--- a/InnerDetector/InDetExample/InDetBeamSpotExample/python/FilterUtils.py
+++ b/InnerDetector/InDetExample/InDetBeamSpotExample/python/FilterUtils.py
@@ -11,7 +11,10 @@ __version__ = '$Id $'
 
 # General setup
 from AthenaCommon.AlgSequence import AthSequencer
-filterSeq = AthSequencer("AthFilterSeq")
+# Leave it named 'filterSeq' for now to not
+# break JOs importing this file. Should be changed
+# to masterSeq to avoid confusion...
+filterSeq = AthSequencer("AthMasterSeq")
 from AthenaPython.PyAthena import StatusCode
 import AthenaPython.PyAthena as PyAthena
 
diff --git a/InnerDetector/InDetMonitoring/InDetAlignmentMonitoring/share/myTopOptions_runReco.py b/InnerDetector/InDetMonitoring/InDetAlignmentMonitoring/share/myTopOptions_runReco.py
index 8ba81279206bdd417933522524bf76768ea4257a..e269d3ab743c63ff791b2f5a9989ff1981108667 100644
--- a/InnerDetector/InDetMonitoring/InDetAlignmentMonitoring/share/myTopOptions_runReco.py
+++ b/InnerDetector/InDetMonitoring/InDetAlignmentMonitoring/share/myTopOptions_runReco.py
@@ -259,7 +259,7 @@ if  addLumiBlockTools :
     # here, the (default) top sequence is used:
     from AthenaCommon.AlgSequence import AlgSequence, AthSequencer
     job = AlgSequence()
-    seq = AthSequencer("AthFilterSeq")
+    seq = AthSequencer("AthMasterSeq")
 
     from GoodRunsListsUser.GoodRunsListsUserConf import *
     seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
diff --git a/InnerDetector/InDetMonitoring/InDetAlignmentMonitoring/share/myTopOptions_runRecoRAW.py b/InnerDetector/InDetMonitoring/InDetAlignmentMonitoring/share/myTopOptions_runRecoRAW.py
index 8b27b0e349186e84173b6ddced2d62246cb639c2..b333953f265c77e7c23a8c3c2b7980c0128e715d 100644
--- a/InnerDetector/InDetMonitoring/InDetAlignmentMonitoring/share/myTopOptions_runRecoRAW.py
+++ b/InnerDetector/InDetMonitoring/InDetAlignmentMonitoring/share/myTopOptions_runRecoRAW.py
@@ -233,7 +233,7 @@ if goodRunList!='' and 'goodRunListArray' in dir() and goodRunListArray!='':
     # here, the (default) top sequence is used:
     from AthenaCommon.AlgSequence import AlgSequence, AthSequencer
     job = AlgSequence()
-    seq = AthSequencer("AthFilterSeq")
+    seq = AthSequencer("AthMasterSeq")
 
     from GoodRunsListsUser.GoodRunsListsUserConf import *
     seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
diff --git a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runEoverPValidationBatch.py b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runEoverPValidationBatch.py
index b56c55fd5b723515f0bf5aeb87b4230155290942..d4c5fe9b2e4d248228c03b68cbfed25dcd6d7f61 100644
--- a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runEoverPValidationBatch.py
+++ b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runEoverPValidationBatch.py
@@ -30,7 +30,7 @@ SkipEvents = 0
 from AthenaCommon.AlgSequence import AlgSequence
 from AthenaCommon.AlgSequence import AthSequencer
 job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 ###############
 # GRL
diff --git a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runEoverPValidationData.py b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runEoverPValidationData.py
index ce681d7b14260914a37848e0e501403f0a5078c9..fb29777d5ca075ca61b93eb3679719bf4229769a 100755
--- a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runEoverPValidationData.py
+++ b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runEoverPValidationData.py
@@ -33,7 +33,7 @@ SkipEvents = 0
 from AthenaCommon.AlgSequence import AlgSequence
 from AthenaCommon.AlgSequence import AthSequencer
 job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 ###############
 # GRL
diff --git a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runMonitoringZmumuValidation_data.py b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runMonitoringZmumuValidation_data.py
index 82b11748409fd5b1cc408ebab1171bf65576b5fe..6dca26becb75268c3534fe758a6cada8409c9ec6 100644
--- a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runMonitoringZmumuValidation_data.py
+++ b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runMonitoringZmumuValidation_data.py
@@ -31,7 +31,7 @@ from AthenaCommon.AlgSequence import AlgSequence
 from AthenaCommon.AlgSequence import AthSequencer
 
 job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 ###############
 # GRL
diff --git a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runZmumuValidation_data.py b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runZmumuValidation_data.py
index a35ceecd5ef711d3b3d6309a8aa3c745b53e55a3..1fbff6114fa72a6d45183e775c29269f2a454f5e 100755
--- a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runZmumuValidation_data.py
+++ b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runZmumuValidation_data.py
@@ -31,7 +31,7 @@ from AthenaCommon.AlgSequence import AlgSequence
 from AthenaCommon.AlgSequence import AthSequencer
 
 job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 ###############
 # GRL
diff --git a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runZmumuValidation_data_OnGrid.py b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runZmumuValidation_data_OnGrid.py
index 3cf3fb53a782a47c97630f6bb70dc4a62b651f6c..36d39cc9538b981e958d684f426f508888cb5ef3 100755
--- a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runZmumuValidation_data_OnGrid.py
+++ b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runZmumuValidation_data_OnGrid.py
@@ -30,7 +30,7 @@ from AthenaCommon.AlgSequence import AlgSequence
 from AthenaCommon.AlgSequence import AthSequencer
 
 job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 ###############
 # GRL
diff --git a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runzmumu_runallmonitoring.py b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runzmumu_runallmonitoring.py
index 770e6b404725663f99c5d440b37b4ccc9f2a1f57..62df689f982401985bd1860ea08f0821775874b6 100644
--- a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runzmumu_runallmonitoring.py
+++ b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runzmumu_runallmonitoring.py
@@ -35,7 +35,7 @@ from AthenaCommon.AlgSequence import AlgSequence
 from AthenaCommon.AlgSequence import AthSequencer
 
 job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 ###############
 # GRL
diff --git a/InnerDetector/InDetRecAlgs/BCM_BackgroundAlgs/run/BCM_BackgroundAlg_jO.py b/InnerDetector/InDetRecAlgs/BCM_BackgroundAlgs/run/BCM_BackgroundAlg_jO.py
index d277b55853d964333c137382b87cee29e02b6ee6..07c590fda832bd0d5ad002cd9a1e89ece26342dd 100644
--- a/InnerDetector/InDetRecAlgs/BCM_BackgroundAlgs/run/BCM_BackgroundAlg_jO.py
+++ b/InnerDetector/InDetRecAlgs/BCM_BackgroundAlgs/run/BCM_BackgroundAlg_jO.py
@@ -18,7 +18,7 @@ from AthenaCommon.AppMgr import ToolSvc
 from AthenaCommon.AlgSequence import AlgSequence
 topSequence = AlgSequence()
 # see details at https://svnweb.cern.ch/trac/atlasoff/browser/DataQuality/GoodRunsListsUser/trunk/share/GoodRunsListsUser_default_data.py#L13
-#seq = AthSequencer("AthFilterSeq") 
+#seq = AthSequencer("AthMasterSeq") 
 
 from AthenaCommon.AthenaCommonFlags import athenaCommonFlags
 import glob
diff --git a/InnerDetector/InDetRecTools/TRT_TrackHoleSearch/share/trt_eff_jobOptions.auto.py b/InnerDetector/InDetRecTools/TRT_TrackHoleSearch/share/trt_eff_jobOptions.auto.py
index 77334363b094b2bf8d1fc12e883e429a19d6eaac..faa853cf39eca90bfe80898a999ec1bb40e1b148 100644
--- a/InnerDetector/InDetRecTools/TRT_TrackHoleSearch/share/trt_eff_jobOptions.auto.py
+++ b/InnerDetector/InDetRecTools/TRT_TrackHoleSearch/share/trt_eff_jobOptions.auto.py
@@ -68,7 +68,7 @@ if do_grl and sample == 'data':
     ## here, the (default) top sequence is used:
     from AthenaCommon.AlgSequence import AlgSequence, AthSequencer
     job = AlgSequence()
-    seq = AthSequencer("AthFilterSeq")
+    seq = AthSequencer("AthMasterSeq")
     
     ## GRL selector, dummy ntuple dumper
     from GoodRunsListsUser.GoodRunsListsUserConf import *
diff --git a/MuonSpectrometer/MuonReconstruction/MuonRecExample/share/SelectEvents_jobOptions.py b/MuonSpectrometer/MuonReconstruction/MuonRecExample/share/SelectEvents_jobOptions.py
index 0040dd6f0697fc7a2c2a173bc514c7bd01456e3e..595a790992033734eb33f249c5fccaa94381d089 100644
--- a/MuonSpectrometer/MuonReconstruction/MuonRecExample/share/SelectEvents_jobOptions.py
+++ b/MuonSpectrometer/MuonReconstruction/MuonRecExample/share/SelectEvents_jobOptions.py
@@ -15,9 +15,9 @@
 from AthenaCommon.GlobalFlags import globalflags
 
 from AthenaCommon.AlgSequence import AthSequencer
-filterSequence = AthSequencer('AthFilterSeq')
+masterSequence = AthSequencer('AthMasterSeq')
 from GaudiSequencer.PyComps import PyEvtFilter
-filterSequence += PyEvtFilter ('EventNumberFilterAlg')
+masterSequence += PyEvtFilter ('EventNumberFilterAlg')
 
 def eventNumber_filter_fct(fname):
     """generate a filter fonction from a file containing lines
@@ -40,7 +40,7 @@ def eventNumber_filter_fct(fname):
 ##     return file_based_event_filter_fct
 
 
-eventFilterAlg = filterSequence.EventNumberFilterAlg
+eventFilterAlg = masterSequence.EventNumberFilterAlg
 if type(EventList) in (list,tuple):
     eventFilterAlg.evt_list = EventList
 elif type(EventList) == str:
diff --git a/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions_NEW.py b/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions_NEW.py
index 76d617b463efe8f3c6e16b7308a9e1a9eb191671..0144a5714fa4c28721369ca6769cc88cca11b07c 100644
--- a/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions_NEW.py
+++ b/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions_NEW.py
@@ -62,7 +62,7 @@ GoodRunsListSelectorTool.PassThrough = False
 ## This Athena job consists of algorithms that loop over events;
 ## here, the (default) top sequence is used:
 #job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 topSequence += seq
 
 from GoodRunsListsUser.GoodRunsListsUserConf import *
diff --git a/PhysicsAnalysis/JetTagging/JetTagAlgs/BTagging/share/BTagging_standAlone.py b/PhysicsAnalysis/JetTagging/JetTagAlgs/BTagging/share/BTagging_standAlone.py
index 523db76a323431c7197831ffca163ac315d14df9..307c1078e62953451617f35a0248fe8638775e74 100755
--- a/PhysicsAnalysis/JetTagging/JetTagAlgs/BTagging/share/BTagging_standAlone.py
+++ b/PhysicsAnalysis/JetTagging/JetTagAlgs/BTagging/share/BTagging_standAlone.py
@@ -195,7 +195,7 @@ if  globalflags.DataSource() == "data" and UseGoodRunLBList:
   # add the filter sequence with its Selector alg (which uses the Selector tool).
   # It is run before the topSequence
   from AthenaCommon.AlgSequence import AthSequencer
-  seq = AthSequencer("AthFilterSeq")
+  seq = AthSequencer("AthMasterSeq")
   from GoodRunsListsUser.GoodRunsListsUserConf import *
   seq += GRLTriggerSelectorAlg('GRLTriggerAlg')
 
diff --git a/Reconstruction/MET/METReconstruction/share/BuildAssociation.py b/Reconstruction/MET/METReconstruction/share/BuildAssociation.py
index 35f8d1e30a8774365499eecdd2b39c6c9b6453ed..635e8a9e66e3226eeb4e1e062e2661213d7040f1 100644
--- a/Reconstruction/MET/METReconstruction/share/BuildAssociation.py
+++ b/Reconstruction/MET/METReconstruction/share/BuildAssociation.py
@@ -82,14 +82,14 @@ assocAlg = CfgMgr.met__METAssocAlg('METAssocAlg',PFOTool=pfotool, TrackSelectorT
 from AthenaCommon.AlgSequence import AlgSequence
 topSequence = AlgSequence()
 from GaudiSequencer.PyComps import PyEvtFilter
-filterseq = CfgMgr.AthSequencer('AthFilterSeq')
+masterSeq = CfgMgr.AthSequencer('AthMasterSeq')
 #the following lines are examples, pick one...
-#filterseq += PyEvtFilter(evt_list=[1980130,287866,1706011,2226793,146377,146604,1904442,1297008,1298451,1072953]) #will execute main sequence only for these eventnumbers
-#filterseq += PyEvtFilter(evt_list=[1108077])
-filterseq += metAlg
-filterseq += assocAlg
-filterseq += utilAlg
-filterseq += makerAlg
+#masterSeq += PyEvtFilter(evt_list=[1980130,287866,1706011,2226793,146377,146604,1904442,1297008,1298451,1072953]) #will execute main sequence only for these eventnumbers
+#masterSeq += PyEvtFilter(evt_list=[1108077])
+masterSeq += metAlg
+masterSeq += assocAlg
+masterSeq += utilAlg
+masterSeq += makerAlg
 
 if verbose:
     metAlg.OutputLevel=VERBOSE
diff --git a/Reconstruction/MET/METReconstruction/share/RunMETAssocTest.py b/Reconstruction/MET/METReconstruction/share/RunMETAssocTest.py
index 57c62bfd3a6c00e57da8cf654e59625de8120582..5758dd26fa696c1ac24ece8c18bdd3ced21558c3 100644
--- a/Reconstruction/MET/METReconstruction/share/RunMETAssocTest.py
+++ b/Reconstruction/MET/METReconstruction/share/RunMETAssocTest.py
@@ -15,9 +15,9 @@ from AthenaCommon.AlgSequence import AlgSequence
 topSequence = AlgSequence()
 
 from GaudiSequencer.PyComps import PyEvtFilter
-filterseq = CfgMgr.AthSequencer("AthFilterSeq")
+masterSeq = CfgMgr.AthSequencer("AthMasterSeq")
 #the following lines are examples, pick one...
-filterseq += PyEvtFilter("PVSoftTrkTail", evt_list=[
+masterSeq += PyEvtFilter("PVSoftTrkTail", evt_list=[
         106239409,
         103677144,
         210091212,
@@ -35,12 +35,12 @@ filterseq += PyEvtFilter("PVSoftTrkTail", evt_list=[
         7747623,
         9713934,
         ])
-topSequence += filterseq
+topSequence += masterSeq
 
-filterseq += CfgMgr.met__METAssocTestAlg("TestMETAssocEMTopo",
+masterSeq += CfgMgr.met__METAssocTestAlg("TestMETAssocEMTopo",
                                          OutputLevel=VERBOSE,
                                          FailOnInconsistency=True)
-filterseq += CfgMgr.met__METAssocTestAlg("TestMETAssocEMPFlow",
+masterSeq += CfgMgr.met__METAssocTestAlg("TestMETAssocEMPFlow",
                                          OutputLevel=VERBOSE,
                                          FailOnInconsistency=True,
                                          METMapSuffix="AntiKt4EMPFlow")
diff --git a/Reconstruction/MET/METReconstruction/share/RunMETReco_Associator_AOD.py b/Reconstruction/MET/METReconstruction/share/RunMETReco_Associator_AOD.py
index f874c0d8d37b1cfb99b5c4f303758aafac00b495..3b6d09d85616b2c16478a7f8bc529ddf9ea8bb8b 100644
--- a/Reconstruction/MET/METReconstruction/share/RunMETReco_Associator_AOD.py
+++ b/Reconstruction/MET/METReconstruction/share/RunMETReco_Associator_AOD.py
@@ -39,9 +39,9 @@ from AthenaCommon.AlgSequence import AlgSequence
 topSequence = AlgSequence()
 
 from GaudiSequencer.PyComps import PyEvtFilter
-#filterseq = CfgMgr.AthSequencer("AthFilterSeq")
+#masterSeq = CfgMgr.AthSequencer("AthMasterSeq")
 #the following lines are examples, pick one...
-# filterseq += PyEvtFilter("PVSoftTrkTail", evt_list=[
+# masterSeq += PyEvtFilter("PVSoftTrkTail", evt_list=[
 #         # 106239409,
 #         # 103677144,
 #         # 210091212,
@@ -59,7 +59,7 @@ from GaudiSequencer.PyComps import PyEvtFilter
 #         # 7747623,
 #         # 9713934,
 #         ])
-#topSequence += filterseq
+#topSequence += masterSeq
 
 ############################################################################
 # Set up an extra associator for testing
@@ -129,11 +129,11 @@ ToolSvc.METMaker_NewAntiKt4EMPFlow.OutputLevel=VERBOSE
 ToolSvc.METMaker_NewAntiKt4EMPFlow.DoRemoveElecTrks=False
 topSequence += makerAlgPF
 
-# filterseq += CfgMgr.met__METAssocTestAlg("TestMETAssocEMTopo",
+# masterSeq += CfgMgr.met__METAssocTestAlg("TestMETAssocEMTopo",
 #                                          OutputLevel=VERBOSE,
 #                                          FailOnInconsistency=True,
 #                                          METMapSuffix="NewAntiKt4EMTopo")
-# filterseq += CfgMgr.met__METAssocTestAlg("TestMETAssocEMPFlow",
+# masterSeq += CfgMgr.met__METAssocTestAlg("TestMETAssocEMPFlow",
 #                                          OutputLevel=VERBOSE,
 #                                          FailOnInconsistency=True,
 #                                          METMapSuffix="NewAntiKt4EMPFlow")
diff --git a/Reconstruction/RecExample/RecExCommon/share/RecExCommon_topOptions.py b/Reconstruction/RecExample/RecExCommon/share/RecExCommon_topOptions.py
index 06b2c54ad47693a1355921ca144f3a92dbebbac8..99e4adfc42f313c75dcefa867a8af9ffa848c7d0 100644
--- a/Reconstruction/RecExample/RecExCommon/share/RecExCommon_topOptions.py
+++ b/Reconstruction/RecExample/RecExCommon/share/RecExCommon_topOptions.py
@@ -1058,8 +1058,8 @@ if rec.doTrigger and rec.doTriggerFilter() and globalflags.DataSource() == 'data
     try:
 ### seq will be our filter sequence
         from AthenaCommon.AlgSequence import AthSequencer
-        seq=AthSequencer("AthFilterSeq")
-        seq+=CfgMgr.EventCounterAlg("AllExecutedEventsAthFilterSeq")
+        seq=AthSequencer("AthMasterSeq")
+        seq+=CfgMgr.EventCounterAlg("AllExecutedEventsAthMasterSeq")
         seq+=topSequence.TrigConfDataIOVChanger
         seq+=topSequence.RoIBResultToAOD
         seq+=topSequence.TrigBSExtraction
diff --git a/Reconstruction/RecExample/RecExTB/share/RecExTB_H6_esdtoesd.py b/Reconstruction/RecExample/RecExTB/share/RecExTB_H6_esdtoesd.py
index 78de2e0e4a04c5b365b81c101a035d0dbd7d44c1..73b6b610a75b17d09188b7bc11699c117af71662 100644
--- a/Reconstruction/RecExample/RecExTB/share/RecExTB_H6_esdtoesd.py
+++ b/Reconstruction/RecExample/RecExTB/share/RecExTB_H6_esdtoesd.py
@@ -147,8 +147,8 @@ if doBeamQuality:
   TBBeamQuality.CheckPrimaryTrack = True
   TBBeamQuality.ScintForPrimaryTrack = [6,7]
   TBBeamQuality.CheckVetoScint = True
-  from AthenaCommon.AppMgr import athFilterSeq
-  athFilterSeq  += TBBeamQuality
+  from AthenaCommon.AppMgr import athMasterSeq
+  athMasterSeq  += TBBeamQuality
   #from AthenaServices.AthenaServicesConf import AthenaEventLoopMgr
   #AthenaEventLoopMgr.FailureMode=2
 
diff --git a/TileCalorimeter/TileRecAlgs/share/jobOptions_TileEventSelector.py b/TileCalorimeter/TileRecAlgs/share/jobOptions_TileEventSelector.py
index 4fb358263f1b3e0f1235a7c3914a25fd6b4b681f..e6bf7df2ea6e85506c8b4d8242c5f8122b27e9d0 100644
--- a/TileCalorimeter/TileRecAlgs/share/jobOptions_TileEventSelector.py
+++ b/TileCalorimeter/TileRecAlgs/share/jobOptions_TileEventSelector.py
@@ -227,7 +227,7 @@ if not ReadESD:
 #import AthenaCommon.AlgSequence as acas
 #job = acas.AlgSequence()
 #
-#seq = acas.AthSequencer("AthFilterSeq")
+#seq = acas.AthSequencer("AthMasterSeq")
 #
 # example how to copy few events from input to output
 #
diff --git a/Tracking/TrkAlignment/TrkAlignGenAlgs/python/SelectEventNumberGetter.py b/Tracking/TrkAlignment/TrkAlignGenAlgs/python/SelectEventNumberGetter.py
index 036ae3d172a52a83c983727833c6de72e631d57a..95da2f5c9e6e43d6c67419ae4480a7e34b7bc7bc 100644
--- a/Tracking/TrkAlignment/TrkAlignGenAlgs/python/SelectEventNumberGetter.py
+++ b/Tracking/TrkAlignment/TrkAlignGenAlgs/python/SelectEventNumberGetter.py
@@ -33,8 +33,8 @@ class SelectEventNumberGetter ( Configured ) :
 
         # add to sequencer
         mlog.info(" now adding to sequencer" )
-        from AthenaCommon.AppMgr import athFilterSeq
-        sequencer = athFilterSeq
+        from AthenaCommon.AppMgr import athMasterSeq
+        sequencer = athMasterSeq
         sequencer += self.SelectEventNumberHandle()
         
         mlog.info(" leaving configure" )
diff --git a/Trigger/TrigAnalysis/TrigEgammaAnalysisTools/share/testTrigEgammaAnalysisTools.py b/Trigger/TrigAnalysis/TrigEgammaAnalysisTools/share/testTrigEgammaAnalysisTools.py
index c9204906db76d749e33f8ecd3cfc3d0f546c41cf..763707849410d0aec5a9e25fd905a847ef097379 100755
--- a/Trigger/TrigAnalysis/TrigEgammaAnalysisTools/share/testTrigEgammaAnalysisTools.py
+++ b/Trigger/TrigAnalysis/TrigEgammaAnalysisTools/share/testTrigEgammaAnalysisTools.py
@@ -89,7 +89,7 @@ if 'GRL' in dir():
     GoodRunsListSelectorTool.OutputLevel = DEBUG
     from AthenaCommon.AlgSequence import AlgSequence,AthSequencer
     topSequence = AlgSequence()
-    seq = AthSequencer("AthFilterSeq")
+    seq = AthSequencer("AthMasterSeq")
     from GoodRunsListsUser.GoodRunsListsUserConf import *
     seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
     seq.GRLTriggerAlg1.GoodRunsListArray = ['PHYS_StandardGRL_All_Good']        ## pick up correct name from inside xml file!
diff --git a/Trigger/TrigAnalysis/TrigEgammaAnalysisTools/share/testTrigEgammaAnalysisToolsGRL.py b/Trigger/TrigAnalysis/TrigEgammaAnalysisTools/share/testTrigEgammaAnalysisToolsGRL.py
index bc68fb6dccbee77aa77fbf14c2715b12bbbc863f..cb574e9530c73aca90ff1cd1c5632b68f6860cfd 100755
--- a/Trigger/TrigAnalysis/TrigEgammaAnalysisTools/share/testTrigEgammaAnalysisToolsGRL.py
+++ b/Trigger/TrigAnalysis/TrigEgammaAnalysisTools/share/testTrigEgammaAnalysisToolsGRL.py
@@ -125,7 +125,7 @@ basePath = '/HLT/Egamma/'
 if 'DOTIER0' in dir():
     from AthenaCommon.AlgSequence import AlgSequence,AthSequencer
     topSequence = AlgSequence()
-    seq = AthSequencer("AthFilterSeq")
+    seq = AthSequencer("AthMasterSeq")
     from GoodRunsListsUser.GoodRunsListsUserConf import *
     seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
     seq.GRLTriggerAlg1.GoodRunsListArray = ['PHYS_StandardGRL_All_Good']        ## pick up correct name from inside xml file!
@@ -154,7 +154,7 @@ if 'DOTIER0' in dir():
 elif 'DO50ns' in dir():
     from AthenaCommon.AlgSequence import AlgSequence,AthSequencer
     topSequence = AlgSequence()
-    seq = AthSequencer("AthFilterSeq")
+    seq = AthSequencer("AthMasterSeq")
     from GoodRunsListsUser.GoodRunsListsUserConf import *
     seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
     seq.GRLTriggerAlg1.GoodRunsListArray = ['PHYS_StandardGRL_All_Good']        ## pick up correct name from inside xml file!
diff --git a/Trigger/TrigAnalysis/TrigEgammaEmulationTool/share/test_TrigEgammaAnalysisToolsWithEmulation.py b/Trigger/TrigAnalysis/TrigEgammaEmulationTool/share/test_TrigEgammaAnalysisToolsWithEmulation.py
index b3e829fbcdbef33a673f515be6accbc8f5e004b6..79a6a269c5a5b537c1f376a391ff46b35834bd4d 100755
--- a/Trigger/TrigAnalysis/TrigEgammaEmulationTool/share/test_TrigEgammaAnalysisToolsWithEmulation.py
+++ b/Trigger/TrigAnalysis/TrigEgammaEmulationTool/share/test_TrigEgammaAnalysisToolsWithEmulation.py
@@ -128,7 +128,7 @@ if inputFileSummary['evt_type'][0] == "IS_DATA":
   ToolSvc += GoodRunsListSelectorTool()
   GoodRunsListSelectorTool.GoodRunsListVec = grllist 
   from GoodRunsListsUser.GoodRunsListsUserConf import *
-  seq = AthSequencer("AthFilterSeq")
+  seq = AthSequencer("AthMasterSeq")
   seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
   seq.GRLTriggerAlg1.GoodRunsListArray = ['PHYS_StandardGRL_All_Good_25ns']  
 ##################################### Mon Tools ##########################################
diff --git a/Trigger/TrigT1/TrigT1CaloCalibUtils/share/L1CaloPprMonitoring_jobOptions.py b/Trigger/TrigT1/TrigT1CaloCalibUtils/share/L1CaloPprMonitoring_jobOptions.py
index 6988af541f34232f77c7cb4c1cfe242a01228b65..99d162dcd3552fc9f8eda12253c07570cb0cd22f 100644
--- a/Trigger/TrigT1/TrigT1CaloCalibUtils/share/L1CaloPprMonitoring_jobOptions.py
+++ b/Trigger/TrigT1/TrigT1CaloCalibUtils/share/L1CaloPprMonitoring_jobOptions.py
@@ -61,7 +61,7 @@ if useGRL == False:
         #                                      '../grl/PeriodI.GRL.xml']
   GoodRunsListSelectorTool.GoodRunsListVec = ['grl/data11_7TeV.periodAllYear_DetStatus-v36-pro10_CoolRunQuery-00-04-08_All_Good.xml','grl/data12_8TeV.periodAllYear_HEAD_All_Good.xml']
   GoodRunsListSelectorTool.PassThrough = False
-  seq = AthSequencer("AthFilterSeq")
+  seq = AthSequencer("AthMasterSeq")
   seq += GRLTriggerSelectorAlg('MyLBCollection')
 
 
diff --git a/graphics/VP1/VP1Algs/python/VP1EvtFilter.py b/graphics/VP1/VP1Algs/python/VP1EvtFilter.py
index ca98a9b8d0b30e87fcc69b62a67ebb117767e637..e18a0abffcfc6fe3719d40eee4155e2a4d3d4800 100644
--- a/graphics/VP1/VP1Algs/python/VP1EvtFilter.py
+++ b/graphics/VP1/VP1Algs/python/VP1EvtFilter.py
@@ -57,7 +57,7 @@ def installEventFilter(filters):
             if evt==filter[1] and (filter[0]==None or filter[0]==run): return not filters[0]
         return filters[0]
     from AthenaCommon.AlgSequence import AthSequencer
-    seq = AthSequencer('AthFilterSeq')
+    seq = AthSequencer('AthMasterSeq')
     from GaudiSequencer.PyComps import PyEvtFilter
     seq += PyEvtFilter ('vp1filteralg')
     seq.vp1filteralg.filter_fct = vp1filter
diff --git a/DataQuality/GoodRunsListsUser/share/GoodRunsListsUser_DQLumiExample.py b/DataQuality/GoodRunsListsUser/share/GoodRunsListsUser_DQLumiExample.py
index 8c74f2c5190e5a2be77f68bfd05403e4cafe1be2..ef73ee5dd12b44e83ee30307db4677ac070841ca 100644
--- a/DataQuality/GoodRunsListsUser/share/GoodRunsListsUser_DQLumiExample.py
+++ b/DataQuality/GoodRunsListsUser/share/GoodRunsListsUser_DQLumiExample.py
@@ -17,12 +17,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ '$TestArea/DataQuality/GoodRunsList
 ## here, the (default) top sequence is used:
 from AthenaCommon.AlgSequence import AlgSequence, AthSequencer
 job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 ## AthFilterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
 ## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 from GoodRunsListsUser.GoodRunsListsUserConf import *
 seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
@@ -17,12 +17,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ '$TestArea/DataQuality/GoodRunsList
 
-## AthFilterSeq is always executed before the top sequence, and is configured such that
+## AthMasterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
@@ -17,12 +17,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ '$TestArea/DataQuality/GoodRunsList
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
-## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
+## In short, the sequence AthMasterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 from GoodRunsListsUser.GoodRunsListsUserConf import *
diff --git a/DataQuality/GoodRunsListsUser/share/GoodRunsListsUser_default.py b/DataQuality/GoodRunsListsUser/share/GoodRunsListsUser_default.py
index f30dc1a70cbba9cd4d54ba67b5641cfea1772e3e..9fab877c4f0668377131236cf3695aa95bfd1195 100644
--- a/DataQuality/GoodRunsListsUser/share/GoodRunsListsUser_default.py
+++ b/DataQuality/GoodRunsListsUser/share/GoodRunsListsUser_default.py
@@ -34,10 +34,10 @@ job = AlgSequence()
 ##   after GRLTriggerAlg1, it is not executed in case GRLTriggerAlg1 rejects an event.
 ###########################################################################################
 
 ## AthFilterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
 seq.GRLTriggerAlg1.GoodRunsListArray  = ['grl_topmix_mu']
 seq.GRLTriggerAlg1.BlackRunsListArray = ['blacklist']
@@ -34,10 +34,10 @@ job = AlgSequence()
 ###########################################################################################
 
-## AthFilterSeq is always executed before the top sequence, and is configured such that
+## AthMasterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
diff --git a/DataQuality/GoodRunsListsUser/share/GoodRunsListsUser_default_data.py b/DataQuality/GoodRunsListsUser/share/GoodRunsListsUser_default_data.py
index 72ed79e000cb9ef98b918f488049ecbd0a74a61e..33d9599a8c3e7c6f4efcd2f24f1857fffcbc0e8f 100644
--- a/DataQuality/GoodRunsListsUser/share/GoodRunsListsUser_default_data.py
+++ b/DataQuality/GoodRunsListsUser/share/GoodRunsListsUser_default_data.py
@@ -8,12 +8,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ '$TestArea/DataQuality/GoodRunsList
 ## here, the (default) top sequence is used:
 from AthenaCommon.AlgSequence import AlgSequence, AthSequencer
 job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 ## AthFilterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
 ## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 from GoodRunsListsUser.GoodRunsListsUserConf import *
 seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
@@ -8,12 +8,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ '$TestArea/DataQuality/GoodRunsList
 
-## AthFilterSeq is always executed before the top sequence, and is configured such that
+## AthMasterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
@@ -8,12 +8,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ '$TestArea/DataQuality/GoodRunsList
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
-## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
+## In short, the sequence AthMasterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 from GoodRunsListsUser.GoodRunsListsUserConf import *
diff --git a/Database/AthenaRoot/AthenaRootComps/share/tests/test_athena_ntuple_filter.py b/Database/AthenaRoot/AthenaRootComps/share/tests/test_athena_ntuple_filter.py
index 5fb6ef2af54fd20236ddf90ba854be574e4b2b62..175c68dff48c64879fde56ef8d8cd942b5716c09 100644
--- a/Database/AthenaRoot/AthenaRootComps/share/tests/test_athena_ntuple_filter.py
+++ b/Database/AthenaRoot/AthenaRootComps/share/tests/test_athena_ntuple_filter.py
@@ -12,10 +12,10 @@ DOWRITE=0
 include("AthenaRootComps/test_athena_ntuple_dumper.py")
 
 ## filter configuration ##
 ##  -> we use the special sequence 'AthFilterSeq' which
 ##      is run before any other algorithm (which are usually in the
 ##      'TopAlg' sequence
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 from GaudiSequencer.PyComps import PyEvtFilter
 seq += PyEvtFilter(
@@ -12,10 +12,10 @@ DOWRITE=0
 
 ## filter configuration ##
-##  -> we use the special sequence 'AthFilterSeq' which
+##  -> we use the special sequence 'AthMasterSeq' which
 ##      is run before any other algorithm (which are usually in the
 ##      'TopAlg' sequence
diff --git a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/jobOptions_useGRL.py b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/jobOptions_useGRL.py
index 1ca8448062adc0b5a52fb90bc55af7fc923e7f2e..0345dc1d92e52a09513941e86103ec23e7f3f6be 100644
--- a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/jobOptions_useGRL.py
+++ b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/jobOptions_useGRL.py
@@ -24,12 +24,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ '$TestArea/InnerDetector/InDetMonit
 ## here, the (default) top sequence is used:
 from AthenaCommon.AlgSequence import AlgSequence, AthSequencer
 job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 ## AthFilterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
 ## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 from GoodRunsListsUser.GoodRunsListsUserConf import *
 seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
@@ -24,12 +24,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ '$TestArea/InnerDetector/InDetMonit
 
-## AthFilterSeq is always executed before the top sequence, and is configured such that
+## AthMasterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
@@ -24,12 +24,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ '$TestArea/InnerDetector/InDetMonit
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
-## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
+## In short, the sequence AthMasterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 from GoodRunsListsUser.GoodRunsListsUserConf import *
diff --git a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runJPsiMonitoring_data.py b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runJPsiMonitoring_data.py
index 55dbdb9a9568cae4f77d6a2beecbea4b38c7b8a2..456b303890313d6847c4c1cf713f553b503f9734 100644
--- a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runJPsiMonitoring_data.py
+++ b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runJPsiMonitoring_data.py
@@ -124,12 +124,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ '$TestArea/InnerDetector/InDetMonit
 ## here, the (default) top sequence is used:
 from AthenaCommon.AlgSequence import AlgSequence, AthSequencer
 job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 ## AthFilterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
 ## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 from GoodRunsListsUser.GoodRunsListsUserConf import *
 seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
@@ -124,12 +124,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ '$TestArea/InnerDetector/InDetMonit
 
-## AthFilterSeq is always executed before the top sequence, and is configured such that
+## AthMasterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
@@ -124,12 +124,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ '$TestArea/InnerDetector/InDetMonit
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
-## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
+## In short, the sequence AthMasterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 from GoodRunsListsUser.GoodRunsListsUserConf import *
diff --git a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runJPsiMonitoring_data_grid.py b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runJPsiMonitoring_data_grid.py
index 6ccaaa845876f4de4bbb5f4a60873585e2e87797..674e101c24a1dd7a1199c8bef95e9570ad8c6ff5 100644
--- a/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runJPsiMonitoring_data_grid.py
+++ b/InnerDetector/InDetMonitoring/InDetPerformanceMonitoring/share/runJPsiMonitoring_data_grid.py
@@ -124,12 +124,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ './data15_13TeV.periodAllYear_DetSt
 ## here, the (default) top sequence is used:
 from AthenaCommon.AlgSequence import AlgSequence, AthSequencer
 job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 
 ## AthFilterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
 ## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 from GoodRunsListsUser.GoodRunsListsUserConf import *
 seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
@@ -124,12 +124,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ './data15_13TeV.periodAllYear_DetSt
 
-## AthFilterSeq is always executed before the top sequence, and is configured such that
+## AthMasterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
@@ -124,12 +124,12 @@ GoodRunsListSelectorTool.GoodRunsListVec = [ './data15_13TeV.periodAllYear_DetSt
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
-## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
+## In short, the sequence AthMasterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 from GoodRunsListsUser.GoodRunsListsUserConf import *
diff --git a/MuonSpectrometer/MuonValidation/MuonDQA/MuonRawDataMonitoring/RpcRawDataMonitoring/share/esd2RpcMon_data_withGRL_triggerSel.py b/MuonSpectrometer/MuonValidation/MuonDQA/MuonRawDataMonitoring/RpcRawDataMonitoring/share/esd2RpcMon_data_withGRL_triggerSel.py
index a039e417febae74ce862c9a78ec893d2c7743b6c..9400e0a50baad05d72429e42a3a26c26790b2a78 100644
--- a/MuonSpectrometer/MuonValidation/MuonDQA/MuonRawDataMonitoring/RpcRawDataMonitoring/share/esd2RpcMon_data_withGRL_triggerSel.py
+++ b/MuonSpectrometer/MuonValidation/MuonDQA/MuonRawDataMonitoring/RpcRawDataMonitoring/share/esd2RpcMon_data_withGRL_triggerSel.py
@@ -186,11 +186,11 @@ GoodRunsListSelectorTool.PassThrough = False
 ## here, the (default) top sequence is used:
 from AthenaCommon.AlgSequence import AlgSequence, AthSequencer
 #job = AlgSequence()
-seq = AthSequencer("AthFilterSeq")
-## AthFilterSeq is always executed before the top sequence, and is configured such that
+seq = AthSequencer("AthMasterSeq")
+## AthMasterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
 ## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 from GoodRunsListsUser.GoodRunsListsUserConf import *
 seq += GRLTriggerSelectorAlg('GRLTriggerAlg1')
@@ -186,11 +186,11 @@ GoodRunsListSelectorTool.PassThrough = False
 ## any follow-up sequence (eg. top sequence) is not executed in case GRLTriggerAlg1 does
 ## not pass the event
-## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
+## In short, the sequence AthMasterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 from GoodRunsListsUser.GoodRunsListsUserConf import *
diff --git a/Reconstruction/RecExample/RecExTB/share/RecExTB_H6_jobOptions.py b/Reconstruction/RecExample/RecExTB/share/RecExTB_H6_jobOptions.py
index 958c19e415a8d285e72a9c32c36a2d4acce25167..4202bfa50334c328a8e70eb8b18dcdf9cdf5498b 100755
--- a/Reconstruction/RecExample/RecExTB/share/RecExTB_H6_jobOptions.py
+++ b/Reconstruction/RecExample/RecExTB/share/RecExTB_H6_jobOptions.py
@@ -307,7 +307,7 @@ os.system('pool_insertFileToCatalog /afs/ipp-garching.mpg.de/home/g/gdp/public/C
 # -----------------------------
 if doLAr:
     theApp.Dlls += [ "TBRec" ]
-    from AthenaCommon.AppMgr import athFilterSeq
+    from AthenaCommon.AppMgr import athMasterSeq
     if not doSim:
         #
         from TBRec.TBRecConf import TBEventStreamer
@@ -331,17 +331,17 @@ if doLAr:
         ToolSvc += EventTypeSelector
         EventInfoStreamer.ToolNames += [ EventTypeSelector ]
         EventInfoStreamer.OutputLevel = ERROR
-        athFilterSeq += EventInfoStreamer
+        athMasterSeq += EventInfoStreamer
         #
         from TBRec.TBRecConf import TBXCryYTableRead
         TBXCryYTableRead = TBXCryYTableRead()
         TBXCryYTableRead.FileName = "xcryo_ytable.txt" 
-        athFilterSeq += TBXCryYTableRead
+        athMasterSeq += TBXCryYTableRead
         #
         from TBRec.TBRecConf import TBPhaseRec
         TBPhaseRec = TBPhaseRec()
         include( "TBRec/H6PhaseRec_jobOptions.py" )
-        athFilterSeq += TBPhaseRec
+        athMasterSeq += TBPhaseRec
         #
         PhaseStreamer = TBEventStreamer("PhaseStreamer")
         from TBRec.TBRecConf import TBPhaseStreamerTool
@@ -350,7 +350,7 @@ if doLAr:
         GuardCut.Guard = 11.0
         ToolSvc += GuardCut
         PhaseStreamer.ToolNames += [ GuardCut ]
-        athFilterSeq  += PhaseStreamer
+        athMasterSeq  += PhaseStreamer
         #
 
 if doBeamDetectors:
@@ -375,27 +375,27 @@ if doBeamDetectors:
 
         ToolSvc += BitSelector 
         BeamStreamer.ToolNames +=  [ BitSelector ]
-        athFilterSeq += BeamStreamer
+        athMasterSeq += BeamStreamer
         #
         from TBRec.TBRecConf import TBBPCRec
         TBBPCRec =  TBBPCRec()
         include( "TBRec/H6BPCRec_jobOptions.py" )
-        athFilterSeq += TBBPCRec
+        athMasterSeq += TBBPCRec
         #   
         from TBRec.TBRecConf import TBScintillatorRec
         TBScintRec =  TBScintillatorRec("TBScintRec")
         include( "TBRec/H6ScintRec_jobOptions.py" )
-        athFilterSeq += TBScintRec
+        athMasterSeq += TBScintRec
         #
         from TBRec.TBRecConf import TBTailCatcherRec
         TBTailCatcherRec = TBTailCatcherRec()
         include( "TBRec/H6TailCatcherRec_jobOptions.py" )
-        athFilterSeq += TBTailCatcherRec
+        athMasterSeq += TBTailCatcherRec
         #
         from TBRec.TBRecConf import TBMWPCRec
         TBMWPCRec = TBMWPCRec()
         include( "TBRec/H6MWPCRec_jobOptions.py" )
-        athFilterSeq += TBMWPCRec
+        athMasterSeq += TBMWPCRec
         #
         from TBRec.TBRecConf import TBPlaneTrackingAlgo
         TBPlaneTrackingAlgo = TBPlaneTrackingAlgo()
@@ -404,7 +404,7 @@ if doBeamDetectors:
             TBPlaneTrackingAlgo.CalibFileName = "BPCAlignment_2004TB_RunI.txt"
         else:
             TBPlaneTrackingAlgo.CalibFileName = "BPCAlignment_2004TB_RunII.txt"
-        athFilterSeq += TBPlaneTrackingAlgo    
+        athMasterSeq += TBPlaneTrackingAlgo    
 
 if doBeamQuality:
 #    if doMon:
@@ -448,8 +448,8 @@ if doBeamQuality:
     TBBeamQuality.CheckTrackReco = True
     
   #topSequence += TBBeamQuality
-  from AthenaCommon.AppMgr import athFilterSeq
-  athFilterSeq  += TBBeamQuality
+  from AthenaCommon.AppMgr import athMasterSeq
+  athMasterSeq  += TBBeamQuality
 
 # -----------------------------
 # LAr detectors
@@ -707,7 +707,7 @@ if doDMSplit:
    DMContSplit.InputDMContainer = "LArCalibrationHitDeadMaterial"
    DMContSplit.OutputDM_Calo = "LArCalibrationHitDeadMaterial_Calo"
    DMContSplit.OutputDM_Leak = "LArCalibrationHitDeadMaterial_Leakage"
-   athFilterSeq += DMContSplit
+   athMasterSeq += DMContSplit
 
 # -----------------------------
 # TB clusters
@@ -863,7 +863,7 @@ if doMakeTopoCluster:
         TBBeamQualityClus.CheckVetoScint = False
         TBBeamQualityClus.CheckClusters = True
         TBBeamQualityClus.CheckTrackReco = False
 #        from AthenaCommon.AppMgr import athFilterSeq
         topSequence += TBBeamQualityClus
 
 if doMakeEMTopoCluster:
@@ -863,7 +863,7 @@ if doMakeTopoCluster:
         TBBeamQualityClus.CheckClusters = True
         TBBeamQualityClus.CheckTrackReco = False
-#        from AthenaCommon.AppMgr import athFilterSeq
+#        from AthenaCommon.AppMgr import athMasterSeq
         topSequence += TBBeamQualityClus
 
diff --git a/TileCalorimeter/TileRec/share/jobOptions_TileEventFilter.py b/TileCalorimeter/TileRec/share/jobOptions_TileEventFilter.py
index b7815adc29a84fc1a9f50871fdcc6080cfc0a431..443c2a5e637a498400442c50a7c2b6f5491126a6 100644
--- a/TileCalorimeter/TileRec/share/jobOptions_TileEventFilter.py
+++ b/TileCalorimeter/TileRec/share/jobOptions_TileEventFilter.py
@@ -5,16 +5,16 @@ from AthenaCommon import CfgMgr
 from AthenaCommon.AlgSequence import AlgSequence, AthSequencer
 topSequence = AlgSequence()
 
-seq = AthSequencer("AthFilterSeq")
+seq = AthSequencer("AthMasterSeq")
 seq += CfgMgr.xAODMaker__EventInfoCnvAlg()
 
 if not 'TriggerTypes' in dir():
     TriggerTypes = []
  
 ## AthFilterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case TileRecFilter does
 ## not pass the event
 ## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 seq += CfgMgr.TileEventFilter(name = 'TileEventFilter'
                             , TriggerTypes = TriggerTypes)
@@ -5,16 +5,16 @@ from AthenaCommon import CfgMgr
     TriggerTypes = []
  
-## AthFilterSeq is always executed before the top sequence, and is configured such that
+## AthMasterSeq is always executed before the top sequence, and is configured such that
 ## any follow-up sequence (eg. top sequence) is not executed in case TileRecFilter does
 ## not pass the event
@@ -5,16 +5,16 @@ from AthenaCommon import CfgMgr
 ## any follow-up sequence (eg. top sequence) is not executed in case TileRecFilter does
 ## not pass the event
-## In short, the sequence AthFilterSeq makes sure that all algs in the job sequence
+## In short, the sequence AthMasterSeq makes sure that all algs in the job sequence
 ## are skipped when an event gets rejects
 seq += CfgMgr.TileEventFilter(name = 'TileEventFilter'
diff --git a/Tools/PyUtils/python/scripts/filter_files.py b/Tools/PyUtils/python/scripts/filter_files.py
index f2409d15fa5229edc32ce5945de8310d2f2b6e6f..4fa7f3b975c4a7b05d9cdb5e15883d3f1db8209c 100644
--- a/Tools/PyUtils/python/scripts/filter_files.py
+++ b/Tools/PyUtils/python/scripts/filter_files.py
@@ -167,10 +167,10 @@ def main(args):
     job = acas.AlgSequence()
     
     ## filter configuration ##
     ##  -> we use the special sequence 'AthFilterSeq' which
     ##      is run before any other algorithm (which are usually in the
     ##      'TopAlg' sequence
-    seq = acas.AthSequencer('AthFilterSeq')
+    seq = acas.AthSequencer('AthMasterSeq')
     
     import GaudiSequencer.PyComps as gspc
     seq += gspc.PyEvtFilter(
@@ -167,10 +167,10 @@ def main(args):
     
     ## filter configuration ##
-    ##  -> we use the special sequence 'AthFilterSeq' which
+    ##  -> we use the special sequence 'AthMasterSeq' which
     ##      is run before any other algorithm (which are usually in the
     ##      'TopAlg' sequence